Introduction
============


.. image:: https://travis-ci.org/trhura/python-myanmar.svg
     :alt: Build Status
.. image:: https://api.codeclimate.com/v1/badges/51163159d264485328a5/test_coverage
   :alt: Test Coverage
.. image:: https://badge.fury.io/py/python-myanmar.svg
    :alt: Pypi Version

This package contains a variety of python modules for Myanmar text proccesing, such as *syllabification*,
*romanization*, *encoding conversion*, *nrc validation* etc. Only python3 is currently supported at the moment.

Installation
============

The package is distributed on PyPI and can be installed with pip::

   pip install python-myanmar

For more information, please read the full documentation
`here <https://python-myanmar.readthedocs.io/en/latest/>`__.
